@@ -25,8 +25,11 @@ if [ "$MACOS_UNIVERSAL" = "ON" ]; then
     ADDITIONAL_CMAKE_FLAGS="$ADDITIONAL_CMAKE_FLAGS -DCMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
 fi
 
+# Disable extra alignment in libbson and libmongocrypt to ensure agreement.
+# libmongocrypt disables by default, but may enable if a system install of libbson is detected with extra alignment.
 common_cmake_args=(
     -DCMAKE_BUILD_TYPE=RelWithDebInfo
+    -DENABLE_EXTRA_ALIGNMENT=OFF
     $ADDITIONAL_CMAKE_FLAGS
 )
 
@@ -40,6 +43,7 @@ if is_true USE_NINJA; then
     bash "$EVG_DIR/ensure-ninja.sh"
 fi
 
+echo "Building libbson ..."
 libbson_install_dir="$pkgconfig_tests_root/install/libbson"
 build_dir="$mongoc_src_dir/_build"
 run_cmake -DENABLE_MONGOC=OFF \
@@ -49,8 +53,9 @@ run_cmake -DENABLE_MONGOC=OFF \
        -B"$build_dir"
 run_cmake --build "$build_dir" --target install --config RelWithDebInfo
 libbson_pkg_config_path="$(native_path "$(dirname "$(find "$libbson_install_dir" -name libbson-1.0.pc)")")"
+echo "Building libbson ... done"
 
-# Build libmongocrypt, static linking against libbson and configured for the PPA
+echo "Build libmongocrypt, static linking against libbson and configured for the PPA ..."
 mongocrypt_install_dir="$pkgconfig_tests_root/install/libmongocrypt"
 build_dir=$pkgconfig_tests_root/mongocrypt-build
 run_cmake -DUSE_SHARED_LIBBSON=OFF \
@@ -60,6 +65,7 @@ run_cmake -DUSE_SHARED_LIBBSON=OFF \
        -H"$LIBMONGOCRYPT_DIR" \
        -B"$build_dir"
 run_cmake --build "$build_dir" --target install --config RelWithDebInfo
+echo "Build libmongocrypt, static linking against libbson and configured for the PPA ... done"
 
 # To validate the pkg-config scripts, we don't want the libbson script to be visible
 mongocrypt_pkg_config_path="$(native_path "$(dirname "$(find "$mongocrypt_install_dir" -name libmongocrypt.pc)")")"
@@ -67,25 +73,28 @@ mongocrypt_pkg_config_path="$(native_path "$(dirname "$(find "$mongocrypt_instal
 export PKG_CONFIG_PATH
 PKG_CONFIG_PATH="$mongocrypt_pkg_config_path:$libbson_pkg_config_path"
 
-echo "Validating pkg-config scripts"
+echo "Validating pkg-config scripts ..."
 pkg-config --debug --print-errors --exists libmongocrypt-static
 pkg-config --debug --print-errors --exists libmongocrypt
+echo "Validating pkg-config scripts ... done"
 
-# Build example-state-machine, static linking against libmongocrypt
+echo "Build example-state-machine, static linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt-static libbson-static-1.0) \
     -o "$pkgconfig_tests_root/example-state-machine" \
     "$LIBMONGOCRYPT_DIR/test/example-state-machine.c" \
     $(pkg-config --libs libmongocrypt-static)
 run_chdir "$LIBMONGOCRYPT_DIR" "$pkgconfig_tests_root/example-state-machine"
+echo "Build example-state-machine, static linking against libmongocrypt ... done"
 
-# Build example-no-bson, static linking against libmongocrypt
+echo "Build example-no-bson, static linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt-static) \
     -o "$pkgconfig_tests_root/example-no-bson" \
     "$LIBMONGOCRYPT_DIR/test/example-no-bson.c" \
     $(pkg-config --libs libmongocrypt-static)
 command "$pkgconfig_tests_root/example-no-bson"
+echo "Build example-no-bson, static linking against libmongocrypt ... done"
 
-# Build example-state-machine, dynamic linking against libmongocrypt
+echo "Build example-state-machine, dynamic linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt libbson-static-1.0) \
     -o "$pkgconfig_tests_root/example-state-machine" \
     "$LIBMONGOCRYPT_DIR/test/example-state-machine.c" \
@@ -93,19 +102,21 @@ gcc $(pkg-config --cflags libmongocrypt libbson-static-1.0) \
 run_chdir "$LIBMONGOCRYPT_DIR" \
     env LD_LIBRARY_PATH="$mongocrypt_install_dir/lib:$mongocrypt_install_dir/lib64" \
     "$pkgconfig_tests_root/example-state-machine"
+echo "Build example-state-machine, dynamic linking against libmongocrypt ... done"
 
-# Build example-no-bson, dynamic linking against libmongocrypt
+echo "Build example-no-bson, dynamic linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt) \
     -o "$pkgconfig_tests_root/example-no-bson" \
     "$LIBMONGOCRYPT_DIR/test/example-no-bson.c" \
     $(pkg-config --libs libmongocrypt)
 env LD_LIBRARY_PATH="$mongocrypt_install_dir/lib:$mongocrypt_install_dir/lib64" \
     "$pkgconfig_tests_root/example-no-bson"
+echo "Build example-no-bson, dynamic linking against libmongocrypt ... done"
 
 # Clean up prior to next execution
 rm -r "$mongocrypt_install_dir"
 
-# Build libmongocrypt, dynamic linking against libbson
+echo "Build libmongocrypt, dynamic linking against libbson ..."
 run_cmake -DUSE_SHARED_LIBBSON=ON \
        -DENABLE_BUILD_FOR_PPA=OFF \
        "${common_cmake_args[@]}" \
@@ -113,8 +124,9 @@ run_cmake -DUSE_SHARED_LIBBSON=ON \
        -H"$LIBMONGOCRYPT_DIR" \
        -B"$build_dir"
 run_cmake --build "$build_dir" --target install --config RelWithDebInfo
+echo "Build libmongocrypt, dynamic linking against libbson ... done"
 
-# Build example-state-machine, static linking against libmongocrypt
+echo "Build example-state-machine, static linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt-static libbson-static-1.0) \
     -o "$pkgconfig_tests_root/example-state-machine" \
     "$LIBMONGOCRYPT_DIR/test/example-state-machine.c" \
@@ -122,16 +134,18 @@ gcc $(pkg-config --cflags libmongocrypt-static libbson-static-1.0) \
 run_chdir "$LIBMONGOCRYPT_DIR" \
     env LD_LIBRARY_PATH="$libbson_install_dir/lib:/$libbson_install_dir/lib64" \
     "$pkgconfig_tests_root/example-state-machine"
+echo "Build example-state-machine, static linking against libmongocrypt ..."
 
-# Build example-no-bson, static linking against libmongocrypt
+echo "Build example-no-bson, static linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt-static) \
     -o "$pkgconfig_tests_root/example-no-bson" \
     "$LIBMONGOCRYPT_DIR/test/example-no-bson.c" \
     $(pkg-config --libs libmongocrypt-static)
 env LD_LIBRARY_PATH="$libbson_install_dir/lib:/$libbson_install_dir/lib64" \
     "$pkgconfig_tests_root/example-no-bson"
+echo "Build example-no-bson, static linking against libmongocrypt ... done"
 
-# Build example-state-machine, dynamic linking against libmongocrypt
+echo "Build example-state-machine, dynamic linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt libbson-static-1.0) \
     -o "$pkgconfig_tests_root/example-state-machine" \
     "$LIBMONGOCRYPT_DIR/test/example-state-machine.c" \
@@ -139,13 +153,15 @@ gcc $(pkg-config --cflags libmongocrypt libbson-static-1.0) \
 run_chdir "$LIBMONGOCRYPT_DIR" \
     env LD_LIBRARY_PATH="$mongocrypt_install_dir/lib:$mongocrypt_install_dir/lib64:$libbson_install_dir/lib:$libbson_install_dir/lib64" \
     "$pkgconfig_tests_root/example-state-machine"
+echo "Build example-state-machine, dynamic linking against libmongocrypt ... done"
 
-# Build example-no-bson, dynamic linking against libmongocrypt
+echo "Build example-no-bson, dynamic linking against libmongocrypt ..."
 gcc $(pkg-config --cflags libmongocrypt) \
     -o "$pkgconfig_tests_root/example-no-bson" \
     "$LIBMONGOCRYPT_DIR/test/example-no-bson.c" \
     $(pkg-config --libs libmongocrypt)
 env LD_LIBRARY_PATH="$mongocrypt_install_dir/lib:$mongocrypt_install_dir/lib64:$libbson_install_dir/lib:$libbson_install_dir/lib64" \
     "$pkgconfig_tests_root/example-no-bson"
+echo "Build example-no-bson, dynamic linking against libmongocrypt ... done"
 
 echo "pkg-config tests PASS"
