@@ -11,6 +11,7 @@ BASE_PYTHON=$(find_python3)
 # MONGOCRYPT_DIR is set by libmongocrypt/.evergreen/config.yml
 MONGOCRYPT_DIR="$MONGOCRYPT_DIR"
 CRYPT_SHARED_DIR="$DRIVERS_TOOLS"
+MONGODB_BINARIES="$DRIVERS_TOOLS/mongodb/bin"
 
 MACHINE=$(uname -m)
 if [ $MACHINE == "aarch64" ]; then
@@ -28,15 +29,20 @@ export PYMONGOCRYPT_LIB
 
 createvirtualenv $PYTHON .venv
 pip install -e .
+pip install uv
 pushd $PYMONGO_DIR
 pip install -e ".[test,encryption]"
 source ${DRIVERS_TOOLS}/.evergreen/csfle/secrets-export.sh
 set -x
-TEST_CRYPT_SHARED=1 DYLD_FALLBACK_LIBRARY_PATH=$CRYPT_SHARED_DIR:${DYLD_FALLBACK_LIBRARY_PATH:-} \
-    LD_LIBRARY_PATH=$CRYPT_SHARED_DIR:${LD_LIBRARY_PATH-} \
-    PATH=$CRYPT_SHARED_DIR:$PATH \
-    AUTH=auth SSL=ssl \
-    .evergreen/run-tests.sh -m encryption
+export DB_USER="bob"
+export DB_PASSWORD="pwd123"
+export CLIENT_PEM="$DRIVERS_TOOLS/.evergreen/x509gen/client.pem"
+export CA_PEM="$DRIVERS_TOOLS/.evergreen/x509gen/ca.pem"
+export DYLD_FALLBACK_LIBRARY_PATH=$CRYPT_SHARED_DIR:${DYLD_FALLBACK_LIBRARY_PATH:-}
+export LD_LIBRARY_PATH=$CRYPT_SHARED_DIR:${LD_LIBRARY_PATH-}
+export PATH=$CRYPT_SHARED_DIR:$MONGODB_BINARIES:$PATH
+export TEST_CRYPT_SHARED="1"
+pytest --maxfail=10 -v -m encryption
 
 popd
 deactivate
