@@ -338,6 +338,8 @@ class Distro(object):
                 return 'buster'
             elif build_os == 'debian11':
                 return 'bullseye'
+            elif build_os == 'debian12':
+                return 'bookworm'
             else:
                 raise Exception("unsupported build_os: %s" % build_os)
         else:
@@ -390,7 +392,7 @@ class Distro(object):
                 "ubuntu2204",
             ]
         elif self.dname == 'debian':
-            return ["debian81", "debian92", "debian10", "debian11"]
+            return ["debian81", "debian92", "debian10", "debian11", "debian12"]
         else:
             raise Exception("BUG: unsupported platform?")
 
@@ -815,15 +817,15 @@ def make_rpm(distro, build_os, arch, spec, srcdir):
         "-D",
         "debug_package %{nil}",
         "-D",
-        f"_arch {arch}",
+        "_arch {}".format(arch),
         "-D",
-        f"_topdir {topdir}",
+        "_topdir {}".format(topdir),
         "-D",
-        f"dist .{distro.release_dist(build_os)}",
+        "dist .{}".format(distro.release_dist(build_os)),
         "-D",
-        f"dynamic_version {spec.pversion(distro)}",
+        "dynamic_version {}".format(spec.pversion(distro)),
         "-D",
-        f"dynamic_release {spec.prelease()}",
+        "dynamic_release {}".format(spec.prelease()),
     ]
 
     # Versions of RPM after 4.4 ignore our BuildRoot tag so we need to
