@@ -53,7 +53,7 @@ void mc_FLE2FindRangePayloadV2_cleanup(mc_FLE2FindRangePayloadV2_t *payload) {
         return false;                                                                                                  \
     }
 
-bool mc_FLE2FindRangePayloadV2_serialize(const mc_FLE2FindRangePayloadV2_t *payload, bson_t *out) {
+bool mc_FLE2FindRangePayloadV2_serialize(const mc_FLE2FindRangePayloadV2_t *payload, bson_t *out, bool use_range_v2) {
     BSON_ASSERT_PARAM(out);
     BSON_ASSERT_PARAM(payload);
 
@@ -131,6 +131,42 @@ bool mc_FLE2FindRangePayloadV2_serialize(const mc_FLE2FindRangePayloadV2_t *payl
         return false;
     }
 
+    if (use_range_v2) {
+        // Encode parameters that were used to generate the mincover.
+        // The crypto parameters are all optionally set. Find payloads may come in pairs (a lower and upper bound).
+        // One of the pair includes the mincover. The other payload was not generated with crypto parameters.
+
+        if (payload->sparsity.set) {
+            if (!BSON_APPEND_INT64(out, "sp", payload->sparsity.value)) {
+                return false;
+            }
+        }
+
+        if (payload->precision.set) {
+            if (!BSON_APPEND_INT32(out, "pn", payload->precision.value)) {
+                return false;
+            }
+        }
+
+        if (payload->trimFactor.set) {
+            if (!BSON_APPEND_INT32(out, "tf", payload->trimFactor.value)) {
+                return false;
+            }
+        }
+
+        if (payload->indexMin.value_type != BSON_TYPE_EOD) {
+            if (!BSON_APPEND_VALUE(out, "mn", &payload->indexMin)) {
+                return false;
+            }
+        }
+
+        if (payload->indexMax.value_type != BSON_TYPE_EOD) {
+            if (!BSON_APPEND_VALUE(out, "mx", &payload->indexMax)) {
+                return false;
+            }
+        }
+    }
+
     return true;
 }
 
