@@ -23,6 +23,17 @@
 #include "./mc-dec128.h"
 #include "./mlib/int128.h"
 
+typedef struct {
+    bool set;
+    bool value;
+} mc_optional_bool_t;
+
+#define OPT_BOOL(val)                                                                                                  \
+    (mc_optional_bool_t) { .set = true, .value = val }
+
+#define OPT_BOOL_C(val)                                                                                                \
+    { .set = true, .value = val }
+
 typedef struct {
     bool set;
     int32_t value;
