@@ -20,6 +20,7 @@
 #include "mc-efc-private.h"
 #include "mc-optional-private.h"
 #include "mc-rangeopts-private.h"
+#include "mc-schema-broker-private.h"
 #include "mongocrypt-buffer-private.h"
 #include "mongocrypt-endpoint-private.h"
 #include "mongocrypt-key-broker-private.h"
@@ -63,6 +64,7 @@ typedef struct __mongocrypt_ctx_opts_t {
     _mongocrypt_buffer_t key_material;
     mongocrypt_encryption_algorithm_t algorithm;
     _mongocrypt_kek_t kek;
+    bool retry_enabled;
 
     struct {
         mongocrypt_index_type_t value;
@@ -87,6 +89,12 @@ typedef struct __mongocrypt_ctx_opts_t {
     } rangeopts;
 } _mongocrypt_ctx_opts_t;
 
+// `_mongocrypt_ctx_opts_t` inherits extended alignment from libbson. To dynamically allocate, use
+// aligned allocation (e.g. BSON_ALIGNED_ALLOC)
+BSON_STATIC_ASSERT2(alignof__mongocrypt_ctx_opts_t,
+                    BSON_ALIGNOF(_mongocrypt_ctx_opts_t)
+                        >= BSON_MAX(BSON_ALIGNOF(_mongocrypt_key_alt_name_t), BSON_ALIGNOF(mc_RangeOpts_t)));
+
 /* All derived contexts may override these methods. */
 typedef struct {
     const char *(*mongo_db_collinfo)(mongocrypt_ctx_t *ctx);
@@ -152,7 +160,10 @@ typedef struct {
     char *target_coll;
 
     _mongocrypt_buffer_t list_collections_filter;
-    _mongocrypt_buffer_t schema;
+
+    // `sb` manages encryption schemas (JSONSchema for CSFLE and encryptedFields for QE).
+    mc_schema_broker_t *sb;
+
     /* TODO CDRIVER-3150: audit + rename these buffers.
      * original_cmd for explicit is {v: <BSON value>}, for auto is the command to
      * be encrypted.
@@ -170,24 +181,6 @@ typedef struct {
     _mongocrypt_buffer_t marked_cmd;
     _mongocrypt_buffer_t encrypted_cmd;
     _mongocrypt_buffer_t key_id;
-    bool used_local_schema;
-    /* collinfo_has_siblings is true if the schema came from a remote JSON
-     * schema, and there were siblings. */
-    bool collinfo_has_siblings;
-    /* encrypted_field_config is set when:
-     * 1. `target_ns` is present in an encrypted_field_config_map.
-     * 2. (TODO MONGOCRYPT-414) The collection has encryptedFields in the
-     * response to listCollections. encrypted_field_config is true if and only if
-     * encryption is using FLE 2.0.
-     * 3. The `bulkWrite` command is processed and needs an empty encryptedFields to be processed by query analysis.
-     * (`bulkWrite` does not support empty JSON schema).
-     */
-    _mongocrypt_buffer_t encrypted_field_config;
-    mc_EncryptedFieldConfig_t efc;
-    // `used_empty_encryptedFields` is true if the collection has no JSON schema or encryptedFields,
-    // yet an empty encryptedFields was constructed to support query analysis.
-    // When true, an empty encryptedFields is sent to query analysis, but not appended to the final command.
-    bool used_empty_encryptedFields;
     /* bypass_query_analysis is set to true to skip the
      * MONGOCRYPT_CTX_NEED_MONGO_MARKINGS state. */
     bool bypass_query_analysis;
@@ -202,6 +195,11 @@ typedef struct {
     const char *cmd_name;
 } _mongocrypt_ctx_encrypt_t;
 
+// `_mongocrypt_ctx_encrypt_t` inherits extended alignment from libbson. To dynamically allocate, use
+// aligned allocation (e.g. BSON_ALIGNED_ALLOC)
+BSON_STATIC_ASSERT2(alignof__mongocrypt_ctx_encrypt_t,
+                    BSON_ALIGNOF(_mongocrypt_ctx_encrypt_t) >= BSON_ALIGNOF(mongocrypt_ctx_t));
+
 typedef struct {
     mongocrypt_ctx_t parent;
     /* TODO CDRIVER-3150: audit + rename these buffers.
@@ -212,6 +210,11 @@ typedef struct {
     _mongocrypt_buffer_t decrypted_doc;
 } _mongocrypt_ctx_decrypt_t;
 
+// `_mongocrypt_ctx_datakey_t` inherits extended alignment from libbson. To dynamically allocate, use
+// aligned allocation (e.g. BSON_ALIGNED_ALLOC)
+BSON_STATIC_ASSERT2(alignof__mongocrypt_ctx_decrypt_t,
+                    BSON_ALIGNOF(_mongocrypt_ctx_decrypt_t) >= BSON_ALIGNOF(mongocrypt_ctx_t));
+
 typedef struct {
     mongocrypt_ctx_t parent;
     mongocrypt_kms_ctx_t kms;
@@ -225,6 +228,11 @@ typedef struct {
     _mongocrypt_buffer_t kmip_secretdata;
 } _mongocrypt_ctx_datakey_t;
 
+// `_mongocrypt_ctx_datakey_t` inherits extended alignment from libbson. To dynamically allocate, use
+// aligned allocation (e.g. BSON_ALIGNED_ALLOC)
+BSON_STATIC_ASSERT2(alignof__mongocrypt_ctx_datakey_t,
+                    BSON_ALIGNOF(_mongocrypt_ctx_datakey_t) >= BSON_ALIGNOF(mongocrypt_ctx_t));
+
 typedef struct _mongocrypt_ctx_rmd_datakey_t _mongocrypt_ctx_rmd_datakey_t;
 
 struct _mongocrypt_ctx_rmd_datakey_t {
@@ -242,12 +250,40 @@ typedef struct {
     _mongocrypt_buffer_t results;
 } _mongocrypt_ctx_rewrap_many_datakey_t;
 
+// `_mongocrypt_ctx_rewrap_many_datakey_t` inherits extended alignment from libbson. To dynamically allocate, use
+// aligned allocation (e.g. BSON_ALIGNED_ALLOC)
+BSON_STATIC_ASSERT2(alignof__mongocrypt_ctx_rewrap_many_datakey_t,
+                    BSON_ALIGNOF(_mongocrypt_ctx_rewrap_many_datakey_t) >= BSON_ALIGNOF(mongocrypt_ctx_t));
+
 typedef struct {
     mongocrypt_ctx_t parent;
     _mongocrypt_buffer_t result;
     mc_EncryptedFieldConfig_t efc;
 } _mongocrypt_ctx_compact_t;
 
+// `_mongocrypt_ctx_compact_t` inherits extended alignment from libbson. To dynamically allocate, use aligned
+// allocation (e.g. BSON_ALIGNED_ALLOC)
+BSON_STATIC_ASSERT2(alignof__mongocrypt_ctx_compact_t,
+                    BSON_ALIGNOF(_mongocrypt_ctx_compact_t) >= BSON_ALIGNOF(mongocrypt_ctx_t));
+
+#define MONGOCRYPT_CTX_ALLOC_SIZE                                                                                      \
+    BSON_MAX(sizeof(_mongocrypt_ctx_encrypt_t),                                                                        \
+             BSON_MAX(sizeof(_mongocrypt_ctx_decrypt_t),                                                               \
+                      BSON_MAX(sizeof(_mongocrypt_ctx_datakey_t),                                                      \
+                               BSON_MAX(sizeof(_mongocrypt_ctx_rewrap_many_datakey_t),                                 \
+                                        sizeof(_mongocrypt_ctx_compact_t)))))
+
+#define MONGOCRYPT_CTX_ALLOC_ALIGNMENT                                                                                 \
+    BSON_MAX(BSON_ALIGNOF(_mongocrypt_ctx_encrypt_t),                                                                  \
+             BSON_MAX(BSON_ALIGNOF(_mongocrypt_ctx_decrypt_t),                                                         \
+                      BSON_MAX(BSON_ALIGNOF(_mongocrypt_ctx_datakey_t),                                                \
+                               BSON_MAX(BSON_ALIGNOF(_mongocrypt_ctx_rewrap_many_datakey_t),                           \
+                                        BSON_ALIGNOF(_mongocrypt_ctx_compact_t)))))
+
+// `_mongocrypt_ctx_t` inherits extended alignment from libbson. To dynamically allocate, use
+// aligned allocation (e.g. BSON_ALIGNED_ALLOC)
+BSON_STATIC_ASSERT2(alignof_mongocrypt_ctx_t, BSON_ALIGNOF(mongocrypt_ctx_t) >= MONGOCRYPT_CTX_ALLOC_ALIGNMENT);
+
 /* Used for option validation. True means required. False means prohibited. */
 typedef enum { OPT_PROHIBITED = 0, OPT_REQUIRED, OPT_OPTIONAL } _mongocrypt_ctx_opt_spec_t;
 
