@@ -26,6 +26,7 @@
 #include "mongocrypt-kek-private.h"
 #include "mongocrypt-log-private.h"
 #include "mongocrypt.h"
+#include <mc-array-private.h>
 
 typedef struct {
     char *tenant_id;
@@ -56,16 +57,44 @@ typedef struct {
     _mongocrypt_endpoint_t *endpoint;
 } _mongocrypt_opts_kms_provider_kmip_t;
 
+typedef struct {
+    // `type` identifies the set field in `value`.
+    _mongocrypt_kms_provider_t type;
+
+    union {
+        _mongocrypt_opts_kms_provider_local_t local;
+        _mongocrypt_opts_kms_provider_aws_t aws;
+        _mongocrypt_opts_kms_provider_azure_t azure;
+        _mongocrypt_opts_kms_provider_gcp_t gcp;
+        _mongocrypt_opts_kms_provider_kmip_t kmip;
+    } value;
+} mc_kms_creds_t;
+
 typedef struct {
     int configured_providers; /* A bit set of _mongocrypt_kms_provider_t */
     int need_credentials;     /* A bit set of _mongocrypt_kms_provider_t */
-    _mongocrypt_opts_kms_provider_local_t local;
-    _mongocrypt_opts_kms_provider_aws_t aws;
-    _mongocrypt_opts_kms_provider_azure_t azure;
-    _mongocrypt_opts_kms_provider_gcp_t gcp;
-    _mongocrypt_opts_kms_provider_kmip_t kmip;
+    // Fields suffixed with `_mut` are mutated when constructing the `_mongocrypt_opts_kms_providers_t`.
+    // Prefer using `_mongocrypt_opts_kms_providers_lookup` to read the values.
+    _mongocrypt_opts_kms_provider_local_t local_mut;
+    _mongocrypt_opts_kms_provider_aws_t aws_mut;
+    _mongocrypt_opts_kms_provider_azure_t azure_mut;
+    _mongocrypt_opts_kms_provider_gcp_t gcp_mut;
+    _mongocrypt_opts_kms_provider_kmip_t kmip_mut;
+    // `named_mut` stores a list of named KMS providers.
+    mc_array_t named_mut;
 } _mongocrypt_opts_kms_providers_t;
 
+void _mongocrypt_opts_kms_providers_init(_mongocrypt_opts_kms_providers_t *kms_providers);
+
+bool _mongocrypt_parse_kms_providers(mongocrypt_binary_t *kms_providers_definition,
+                                     _mongocrypt_opts_kms_providers_t *kms_providers,
+                                     mongocrypt_status_t *status,
+                                     _mongocrypt_log_t *log);
+
+bool _mongocrypt_opts_kms_providers_lookup(const _mongocrypt_opts_kms_providers_t *kms_providers,
+                                           const char *kmsid,
+                                           mc_kms_creds_t *out);
+
 typedef struct {
     mongocrypt_log_fn_t log_fn;
     void *log_ctx;
@@ -86,11 +115,11 @@ typedef struct {
     mstr crypt_shared_lib_override_path;
 
     bool use_need_kms_credentials_state;
+    bool use_need_mongo_collinfo_with_db_state;
     bool bypass_query_analysis;
 
-    // When creating new encrypted payloads,
-    // use V2 variants of the FLE2 datatypes.
-    bool use_fle2_v2;
+    // Use the Queryable Encryption Range V2 protocol.
+    bool use_range_v2;
 } _mongocrypt_opts_t;
 
 void _mongocrypt_opts_kms_providers_cleanup(_mongocrypt_opts_kms_providers_t *kms_providers);
@@ -120,6 +149,14 @@ bool _mongocrypt_opts_kms_providers_validate(_mongocrypt_opts_t *opts,
  */
 bool _mongocrypt_parse_optional_utf8(const bson_t *bson, const char *dotkey, char **out, mongocrypt_status_t *status);
 
+/*
+ * Parse an optional boolean value from BSON.
+ * @dotkey may be a dot separated key like: "a.b.c".
+ * @*out is set to a copy of the value if found, false otherwise.
+ * Returns true if no error occured.
+ */
+bool _mongocrypt_parse_optional_bool(const bson_t *bson, const char *dotkey, bool *out, mongocrypt_status_t *status);
+
 /*
  * Parse a required UTF-8 value from BSON.
  * @dotkey may be a dot separated key like: "a.b.c".
@@ -200,4 +237,8 @@ bool _mongocrypt_check_allowed_fields_va(const bson_t *bson, const char *dotkey,
 #define _mongocrypt_check_allowed_fields(bson, path, status, ...)                                                      \
     _mongocrypt_check_allowed_fields_va(bson, path, status, __VA_ARGS__, NULL)
 
+bool mc_kmsid_parse(const char *kmsid,
+                    _mongocrypt_kms_provider_t *type_out,
+                    const char **name_out,
+                    mongocrypt_status_t *status);
 #endif /* MONGOCRYPT_OPTS_PRIVATE_H */
