@@ -14,6 +14,7 @@
  * limitations under the License.
  */
 
+#include "mongocrypt.h"
 #include "mlib/error.h"
 #include "mlib/path.h"
 #include "mlib/thread.h"
@@ -24,6 +25,7 @@
 #include "mongocrypt-binary-private.h"
 #include "mongocrypt-cache-collinfo-private.h"
 #include "mongocrypt-cache-key-private.h"
+#include "mongocrypt-cache-private.h"
 #include "mongocrypt-config.h"
 #include "mongocrypt-crypto-private.h"
 #include "mongocrypt-log-private.h"
@@ -116,8 +118,6 @@ mongocrypt_t *mongocrypt_new(void) {
     crypt->status = mongocrypt_status_new();
     _mongocrypt_opts_init(&crypt->opts);
     _mongocrypt_log_init(&crypt->log);
-    // Default to using FLEv2 (aka QEv2)
-    crypt->opts.use_fle2_v2 = true;
     crypt->ctx_counter = 1;
     crypt->cache_oauth = mc_mapof_kmsid_to_token_new();
     crypt->csfle = (_mongo_crypt_v1_vtable){.okay = false};
@@ -146,13 +146,6 @@ mongocrypt_t *mongocrypt_new(void) {
         }                                                                                                              \
     }
 
-bool mongocrypt_setopt_fle2v2(mongocrypt_t *crypt, bool enable) {
-    ASSERT_MONGOCRYPT_PARAM_UNINIT(crypt);
-
-    crypt->opts.use_fle2_v2 = enable;
-    return true;
-}
-
 bool mongocrypt_setopt_use_range_v2(mongocrypt_t *crypt) {
     ASSERT_MONGOCRYPT_PARAM_UNINIT(crypt);
 
@@ -167,6 +160,18 @@ bool mongocrypt_setopt_log_handler(mongocrypt_t *crypt, mongocrypt_log_fn_t log_
     return true;
 }
 
+bool mongocrypt_setopt_retry_kms(mongocrypt_t *crypt, bool enable) {
+    ASSERT_MONGOCRYPT_PARAM_UNINIT(crypt);
+    crypt->retry_enabled = enable;
+    return true;
+}
+
+bool mongocrypt_setopt_enable_multiple_collinfo(mongocrypt_t *crypt) {
+    ASSERT_MONGOCRYPT_PARAM_UNINIT(crypt);
+    crypt->multiple_collinfo_enabled = true;
+    return true;
+}
+
 bool mongocrypt_setopt_kms_provider_aws(mongocrypt_t *crypt,
                                         const char *aws_access_key_id,
                                         int32_t aws_access_key_id_len,
@@ -214,6 +219,17 @@ bool mongocrypt_setopt_kms_provider_aws(mongocrypt_t *crypt,
     return true;
 }
 
+bool mongocrypt_setopt_key_expiration(mongocrypt_t *crypt, uint64_t cache_expiration_ms) {
+    ASSERT_MONGOCRYPT_PARAM_UNINIT(crypt);
+    if (cache_expiration_ms > INT64_MAX) {
+        mongocrypt_status_t *status = crypt->status;
+        CLIENT_ERR("expiration time must be less than %" PRId64 ", but got %" PRIu64, INT64_MAX, cache_expiration_ms);
+        return false;
+    }
+    crypt->cache_key.expiration = cache_expiration_ms;
+    return true;
+}
+
 char *_mongocrypt_new_string_from_bytes(const void *in, int len) {
     const int max_bytes = 100;
     const int chars_per_byte = 2;
