@@ -2,13 +2,15 @@
 #if defined(__has_include) && !(defined(_GNU_SOURCE) || defined(_DARWIN_C_SOURCE))
 #if __has_include(<features.h>)
 // We're using a glibc-compatible library
+#if !defined(_GNU_SOURCE)
 #define _GNU_SOURCE
+#endif
 #elif __has_include(<Availability.h>)
 // We're on Apple/Darwin
 #define _DARWIN_C_SOURCE
 #endif
 #else // No __has_include
-#if __GNUC__ < 5
+#if __GNUC__ < 5 && !defined(_GNU_SOURCE)
 // Best guess on older GCC is that we are using glibc
 #define _GNU_SOURCE
 #endif
@@ -95,26 +97,42 @@ mcr_dll_path_result mcr_dll_path(mcr_dll dll) {
     return (mcr_dll_path_result){.error_string = mstr_copy_cstr("Handle not found in loaded modules")};
 }
 
+bool mcr_dll_path_supported(void) {
+    return true;
+}
+
 #elif defined(__linux__) || defined(__FreeBSD__)
 
 #include <link.h>
 
 mcr_dll_path_result mcr_dll_path(mcr_dll dll) {
-    struct link_map *map;
+    struct link_map *map = NULL;
     int rc = dlinfo(dll._native_handle, RTLD_DI_LINKMAP, &map);
     if (rc == 0) {
+        assert(NULL != map);
         return (mcr_dll_path_result){.path = mstr_copy_cstr(map->l_name)};
     } else {
         return (mcr_dll_path_result){.error_string = mstr_copy_cstr(dlerror())};
     }
 }
 
+bool mcr_dll_path_supported(void) {
+    return true;
+}
+
 #elif defined(_WIN32)
 
 // Handled in os_win/os_dll.c
 
 #else
 
-#error "Don't know how to do mcr_dll_path() on this platform"
+mcr_dll_path_result mcr_dll_path(mcr_dll dll) {
+    return (mcr_dll_path_result){.error_string =
+                                     mstr_copy_cstr("Don't know how to do mcr_dll_path() on this platform")};
+}
+
+bool mcr_dll_path_supported(void) {
+    return false;
+}
 
 #endif
